Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(52)

Unified Diff: generated/googleapis/lib/civicinfo/us_v1.dart

Issue 698403003: Api roll 5: 2014-11-05 (Closed) Base URL: git@github.com:dart-lang/googleapis.git@master
Patch Set: Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: generated/googleapis/lib/civicinfo/us_v1.dart
diff --git a/generated/googleapis/lib/civicinfo/us_v1.dart b/generated/googleapis/lib/civicinfo/us_v1.dart
index a152242378f5ef5577dacf718831ca4567f79606..8d07e46351cc74e2992594cda68c123e7c88eb60 100644
--- a/generated/googleapis/lib/civicinfo/us_v1.dart
+++ b/generated/googleapis/lib/civicinfo/us_v1.dart
@@ -1311,16 +1311,16 @@ class Official {
/**
* A location where a voter can vote. This may be an early vote site or an
* election day voting location.
*/
class PollingLocation {
- /** The address of the location */
+ /** The address of the location. */
SimpleAddressType address;
/**
* The last date that this early vote site may be used. This field is not
* populated for polling locations.
*/
core.String endDate;
@@ -1332,12 +1332,14 @@ class PollingLocation {
core.String id;
/**
* The name of the early vote site. This field is not populated for polling
* locations.
*/
core.String name;
- /** Notes about this location (e.g. accessibility ramp or entrance to use) */
+ /**
+ * Notes about this location (e.g. accessibility ramp or entrance to use).
+ */
core.String notes;
/** A description of when this location is open. */
@@ -1350,14 +1352,14 @@ class PollingLocation {
core.List<Source> sources;
/**
* The first date that this early vote site may be used. This field is not
* populated for polling locations.
*/
core.String startDate;
/**
* The services provided by this early vote site. This field is not populated
* for polling locations.
*/
core.String voterServices;
@@ -1680,11 +1682,20 @@ class VoterInfoRequest {
/** The result of a voter info lookup query. */
class VoterInfoResponse {
- /** Contests that will appear on the voter's ballot */
+ /** Contests that will appear on the voter's ballot. */
core.List<Contest> contests;
/**
- * Locations where the voter is eligible to vote early, prior to election day
+ * Locations where a voter is eligible to drop off a completed ballot. The
+ * voter must have received and completed a ballot prior to arriving at the
+ * location. The location may not have ballots available on the premises.
+ * These locations could be open on or before election day as indicated in the
+ * pollingHours field.
+ */
+ core.List<PollingLocation> dropOffLocations;
+
+ /**
+ * Locations where the voter is eligible to vote early, prior to election day.
*/
core.List<PollingLocation> earlyVoteSites;
@@ -1700,12 +1711,7 @@ class VoterInfoResponse {
/** The normalized version of the requested address */
SimpleAddressType normalizedInput;
- /**
- * Locations where the voter is eligible to vote on election day. For states
- * with mail-in voting only, these locations will be nearby drop box
- * locations. Drop box locations are free to the voter and may be used instead
- * of placing the ballot in the mail.
- */
+ /** Locations where the voter is eligible to vote on election day. */
core.List<PollingLocation> pollingLocations;
/** Not documented yet. */
@@ -1731,6 +1737,9 @@ class VoterInfoResponse {
if (_json.containsKey("contests")) {
contests = _json["contests"].map((value) => new Contest.fromJson(value)).toList();
}
+ if (_json.containsKey("dropOffLocations")) {
+ dropOffLocations = _json["dropOffLocations"].map((value) => new PollingLocation.fromJson(value)).toList();
+ }
if (_json.containsKey("earlyVoteSites")) {
earlyVoteSites = _json["earlyVoteSites"].map((value) => new PollingLocation.fromJson(value)).toList();
}
@@ -1762,6 +1771,9 @@ class VoterInfoResponse {
if (contests != null) {
_json["contests"] = contests.map((value) => (value).toJson()).toList();
}
+ if (dropOffLocations != null) {
+ _json["dropOffLocations"] = dropOffLocations.map((value) => (value).toJson()).toList();
+ }
if (earlyVoteSites != null) {
_json["earlyVoteSites"] = earlyVoteSites.map((value) => (value).toJson()).toList();
}
@@ -1311,16 +1311,16 @@ class Official {
/**
- * A location where a voter can vote. This may be an early vote site or an
- * election day voting location.
+ * A location where a voter can vote. This may be an early vote site, an
+ * election day voting location, or a drop off location for a completed ballot.
*/
class PollingLocation {
@@ -1311,16 +1311,16 @@ class Official {
SimpleAddressType address;
/**
- * The last date that this early vote site may be used. This field is not
- * populated for polling locations.
+ * The last date that this early vote site or drop off location may be used.
+ * This field is not populated for polling locations.
*/
core.String endDate;
@@ -1332,12 +1332,14 @@ class PollingLocation {
core.String id;
/**
- * The name of the early vote site. This field is not populated for polling
- * locations.
+ * The name of the early vote site or drop off location. This field is not
+ * populated for polling locations.
*/
core.String name;
@@ -1350,14 +1352,14 @@ class PollingLocation {
core.List<Source> sources;
/**
- * The first date that this early vote site may be used. This field is not
- * populated for polling locations.
+ * The first date that this early vote site or drop off location may be used.
+ * This field is not populated for polling locations.
*/
core.String startDate;
@@ -1350,14 +1352,14 @@ class PollingLocation {
core.String startDate;
/**
- * The services provided by this early vote site. This field is not populated
- * for polling locations.
+ * The services provided by this early vote site or drop off location. This
+ * field is not populated for polling locations.
*/
core.String voterServices;

Powered by Google App Engine
This is Rietveld 408576698